==> nucliadb_node_binding-0.7.3.tar.gz: nucliadb_node_binding-0.7.3/local_dependencies/nucliadb_node/src/bin/payload_test.rs <==
// Copyright (C) 2021 Bosutech XXI S.L.
//
// nucliadb is offered under the AGPL v3.0 and as commercial software.
// For commercial licensing, contact us at info@nuclia.com.
//
// AGPL:
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

use std::io::Cursor;

use nucliadb_core::protos::*;
use nucliadb_node::reader::NodeReaderService;
use nucliadb_node::writer::NodeWriterService;
use prost::Message;

fn main() -> anyhow::Result<()> {
    let mut writer = NodeWriterService::new();
    let reader = NodeReaderService::new();

    let resources_dir = std::path::Path::new("/path/to/data");
    let new_shard = writer.new_shard(&NewShardRequest::default())?;
    let shard_id = ShardId { id: new_shard.id };
    assert!(resources_dir.exists());
    for file_path in std::fs::read_dir(resources_dir).unwrap() {
        let file_path = file_path.unwrap().path();
        println!("processing {file_path:?}");
        let content = std::fs::read(&file_path).unwrap();
        let resource = Resource::decode(&mut Cursor::new(content)).unwrap();
        println!("Adding resource {}", file_path.display());
        let res = writer.set_resource(&shard_id, &resource).unwrap();
        assert!(res.is_some());
        println!("Resource added: {:?}", res.unwrap());
        let info = reader
            .get_shard(&shard_id)
            .unwrap()
            .get_info(&GetShardRequest::default())
            .unwrap();
        println!("Sentences {}", info.sentences);
        println!("Paragraphs {}", info.paragraphs);
        println!("resources {}", info.resources);
    }
    Ok(())
}

==> nucliadb_node_binding-2.26.0.post262.tar.gz: nucliadb_node_binding-2.26.0.post262/local_dependencies/nucliadb_node/src/bin/payload_test.rs <==
// Copyright (C) 2021 Bosutech XXI S.L.
//
// nucliadb is offered under the AGPL v3.0 and as commercial software.
// For commercial licensing, contact us at info@nuclia.com.
//
// AGPL:
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

use std::io::Cursor;

use nucliadb_core::protos::*;
use nucliadb_core::NodeResult;
use nucliadb_node::env;
use nucliadb_node::shards::metadata::ShardMetadata;
use nucliadb_node::shards::providers::unbounded_cache::{
    UnboundedShardReaderCache, UnboundedShardWriterCache,
};
use nucliadb_node::shards::providers::{ShardReaderProvider, ShardWriterProvider};
use prost::Message;

fn main() -> NodeResult<()> {
    let writer = UnboundedShardWriterCache::new(env::shards_path());
    let reader = UnboundedShardReaderCache::new(env::shards_path());
    let resources_dir = std::path::Path::new("/path/to/data");

    let metadata = ShardMetadata::from(NewShardRequest::default());
    let new_shard = writer.create(metadata)?;
    let shard_id = ShardId { id: new_shard.id };
    assert!(resources_dir.exists());
    for file_path in std::fs::read_dir(resources_dir).unwrap() {
        let file_path = file_path.unwrap().path();
        println!("processing {file_path:?}");

        let content = std::fs::read(&file_path).unwrap();
        let resource = Resource::decode(&mut Cursor::new(content)).unwrap();
        println!("Adding resource {}", file_path.display());

        writer.load(shard_id.id.clone())?;
        let shard_writer = writer.get(shard_id.id.clone()).unwrap();
        let res = shard_writer.set_resource(&resource);
        assert!(res.is_ok());
        println!("Resource added: {:?}", res.unwrap());

        reader.load(shard_id.id.clone())?;
        let shard_reader = reader.get(shard_id.id.clone()).unwrap();
        let info = shard_reader.get_info(&GetShardRequest::default())?;
        println!("Sentences {}", info.sentences);
        println!("Paragraphs {}", info.paragraphs);
        println!("Fields {}", info.fields);
    }
    Ok(())
}
